<p align="center">
<br />
<img src="https://github.com/enceladus-rex/webauthn-rp/raw/master/docs/source/_static/webauthn-rp-logo.png" />
</p>
<br />
<hr />

![Travis Build](https://img.shields.io/travis/com/enceladus-rex/webauthn-rp/master.svg)
![Codecov](https://img.shields.io/codecov/c/github/enceladus-rex/webauthn-rp/master.svg)
![Read the Docs](https://img.shields.io/readthedocs/webauthn-rp/latest.svg)

WebAuthn-RP is a Python 3 library to manage credentials that conform to the 
[Web Authentication specification](https://www.w3.org/TR/webauthn/).

You can use it as a relying party on the server-side to interface with your database and routing layers. It is 
designed to work across different frameworks without any changes.

## Getting Started

To quickly install the library you can use pip:

```
pip install webauthn-rp
```

To learn more about how to use the library (which is currently in alpha), please visit the documentation at [readthedocs](https://webauthn-rp.readthedocs.io/en/latest/).

You can also find some of the examples which are covered in the docs under `/examples`.
